<?php
/*
Sample PHP/SOAP Client for IMS Webservice
By: James Hogan
Date: 8/25/2010

This program shows several methods of requesting a rate quote from the IMS Webservice.

*/
header("Content-type: text/xml");
set_include_path("C:/projects/vtrack/ZendFramework-1.10.7/library");

//Location where the IMS Webservice is running
//$webServiceUrl = "http://localhost/imsservice.php?wsdl";
$webServiceUrl = "http://apps.imstransport.com/imsservice.php?wsdl";

//Use the public key for your company (provided by IMS)
$publicKey = "YOURPUBLICKEYHERE";

//the private key should remain a secret and never be sent in the webservice
$privateKey = "YOURPRIVATEKEYHERE";

//A valid username/password for a user with access rights to the IMS system.
$username = "USERNAMETOIMPERSONATEHERE";
$password = encrypt("PASSWORDFORABOVEUSERNAMEHERE",$privateKey);

//Declare a dynamic/inland location
$inlandLoc = "07724"; //Eatontown NJ
if( isset($_REQUEST['zip']) ) {
  $inlandLoc = $_REQUEST['zip'];
}

try {
  
  //Create a SOAP Client
  include_once('C:/projects/vtrack/ZendFramework-1.10.7/library/Zend/Loader.php');
	Zend_Loader::loadClass('Zend_Soap_Client');
	$client = new Zend_Soap_Client($webServiceUrl, array('encoding' => 'UTF-8'));

  //Uncomment a line to run the sample - descriptions of each sample are above each funcation declaration
  echo '<xmls>';
  echo '<xml>' . sample1() . '</xml>';
  echo '<xml>' . sample2() . '</xml>'; 
  echo '<xml>' . sample3('a') . '</xml>'; 
  echo '<xml>' . sample3('b') . '</xml>'; 
  echo '<xml>' . sample3('New York, NY') . '</xml>'; 
  echo '<xml>' . sample4() . '</xml>';
  echo '<xml>' . sample5() . '</xml>';
  echo '<xml>' . sample6('07724') . '</xml>';
  echo '</xmls>';

} catch(Zend_Exception $e) {
    echo $e->getMessage();
}

exit(0);

//Function to encrypt password
function encrypt($string, $key) { 
  $result = ''; 
  for($i=0; $i<strlen($string); $i++) { 
    $char = substr($string, $i, 1); 
    $keychar = substr($key, ($i % strlen($key))-1, 1); 
    $char = (ord($char)+ord($keychar)) . "|";
    $result.=$char; 
  }
  return $result;
}

//Sample 1 - this is the most basic example - given a ZipCode - find the closest empty locations and 
//then get all of the quotes from all of the closest empty locations to the inland location.
function sample1() {
  global $client;
  global $publicKey;
  global $username;
  global $password;
  global $inlandLoc;

  $quotes = "";
  $possibleEmpties = $client->locEmpties($publicKey,$username,$password,$inlandLoc);
  $xmlPossibleEmpties = new DOMDocument();
  $xmlPossibleEmpties->preserveWhiteSpace = false;
  $xmlPossibleEmpties->formatOutput = true;
  $xmlPossibleEmpties->loadxml($possibleEmpties);
  
  $xpath = new DOMXPath($xmlPossibleEmpties);
  $query = "//data/locations/location";
  $emtpyLocs = $xpath->query($query);
  
  foreach ($emtpyLocs as $emptyLoc) {
    $closestLoc = $emptyLoc->getElementsByTagName('locationname')->item(0)->nodeValue;     
    $quotes .= "<results>";
    $quotes .= "<emptylocation>" . $closestLoc . "</emptylocation>";
    $quotes .= $client->getQuote($publicKey,$username,$password,1,"ALL","D","L","L","X","ALL","DV/HC",$closestLoc,$inlandLoc,$closestLoc,"","Y","N","N");
    $quotes .= "</results>";
  }  
  return $quotes;
}

//Sample 2 - another basic example - given a ZipCode - find the closest empty locations that
//are common empty locations and then get all of the quotes from all of the closest empty 
//locations for the inland location and where the empty location is less than 500 miles from 
//the inland location
function sample2() {
  global $client;
  global $publicKey;
  global $username;
  global $password;
  global $inlandLoc;

  $quotes = "";
  $possibleEmpties = $client->locEmpties($publicKey,$username,$password,$inlandLoc);
  $xmlPossibleEmpties = new DOMDocument();
  $xmlPossibleEmpties->preserveWhiteSpace = false;
  $xmlPossibleEmpties->formatOutput = true;
  $xmlPossibleEmpties->loadxml($possibleEmpties);
  
  $xpath = new DOMXPath($xmlPossibleEmpties);
  $query = "//data/locations/location";
  $emtpyLocs = $xpath->query($query);
  
  //
  foreach ($emtpyLocs as $emptyLoc) {
    if( $emptyLoc->getElementsByTagName('commonInd')->item(0)->nodeValue == 'Y' && $emptyLoc->getElementsByTagName('miles')->item(0)->nodeValue < 500 ) {
      $closestLoc = $emptyLoc->getElementsByTagName('locationname')->item(0)->nodeValue;     
      $quotes .= "<results>";
      $quotes .= "<emptylocation>" . $closestLoc . "</emptylocation>";
      $quotes .= $client->getQuote($publicKey,$username,$password,1,"ALL","D","L","L","X","ALL","DV/HC",$closestLoc,$inlandLoc,$closestLoc,"","Y","N","N");
      $quotes .= "</results>";
    }
  }  
  return $quotes;
}

//Sample 3 - Get a list of locations that match the passed search string
function sample3($search) {
  global $client;
  global $publicKey;
  global $username;
  global $password;
  global $inlandLoc;
  $locs = $client->locSearch($publicKey,$username,$password,$search);
  return $locs;
}

//Sample 4 - get a quote for the one clostest empty
function sample4() {
  global $client;
  global $publicKey;
  global $username;
  global $password;
  global $inlandLoc;
  
  $quotes = "";
  $possibleEmpties = $client->locEmpties($publicKey,$username,$password,$inlandLoc);
  $xmlPossibleEmpties = new DOMDocument();
  $xmlPossibleEmpties->preserveWhiteSpace = false;
  $xmlPossibleEmpties->formatOutput = true;
  $xmlPossibleEmpties->loadxml($possibleEmpties);
  
  $xpath = new DOMXPath($xmlPossibleEmpties);
  $query = "//data/locations/location";
  $emtpyLocs = $xpath->query($query);
  
  foreach ($emtpyLocs as $emptyLoc) {
    $closestLoc = $emptyLoc->getElementsByTagName('locationname')->item(0)->nodeValue;
    $quotes .= "<results>";
    $quotes .= "<emptylocation>" . $closestLoc . "</emptylocation>";
    $quotes .= $client->getQuote($publicKey,$username,$password,1,"ALL","D","L","L","X","ALL","DV/HC",$closestLoc,$inlandLoc,$closestLoc,"","Y","N","N");
    $quotes .= "</results>";
    break;
  }
  //}
  return $quotes;
}

//Sample 5 - get a quote for a non-door move
function sample5() {
  global $client;
  global $publicKey;
  global $username;
  global $password;
  global $inlandLoc;
  
  $quotes = "";
  $possibleEmpties = $client->locEmpties($publicKey,$username,$password,$inlandLoc);
  $xmlPossibleEmpties = new DOMDocument();
  $xmlPossibleEmpties->preserveWhiteSpace = false;
  $xmlPossibleEmpties->formatOutput = true;
  $xmlPossibleEmpties->loadxml($possibleEmpties);
  
  $xpath = new DOMXPath($xmlPossibleEmpties);
  
  $query = "//data/result";
  $result = $xpath->query($query);
  
  if( $result->item(0)->nodeValue == "ok" ) { 
    $query = "//data/locations/location";  
    $emtpyLocs = $xpath->query($query);
      $closestLoc = $emtpyLocs->item(0)->getElementsByTagName('locationname')->item(0)->nodeValue;
      $quotes .= "<results>";
      $quotes .= "<emptylocation>" . $closestLoc . "</emptylocation>";
      $quotes .= $client->getQuote($publicKey,$username,$password,1,"ALL","ND","D","L","B","ALL","DV/HC","NEW YORK, NY","CHICAGO, IL","","","N","N","N");
      $quotes .= "</results>";
  }else{
    $quotes .= "<results>";
    $quotes .= "<result>" . $result->item(0)->nodeValue . "</result>";
    $query = "//data/resultDesc";
    $resDesc = $xpath->query($query);
    $quotes .= "<resDesc>" . $resDesc->item(0)->nodeValue . "</resDesc>";
    $quotes .= "</results>";    
  }
  return $quotes;
}

function sample6($inlandLoc) {
  global $client;
  global $publicKey;
  global $username;
  global $password;
  global $inlandLoc;
  
  $quotes = "";
  $possibleEmpties = $client->locEmpties($publicKey,$username,$password,$inlandLoc);
  return $possibleEmpties;
}

?>